==> devextreme-23.1.9.tgz: package/bundles/__internal/grids/data_grid/m_editing.js <==
/**
 * DevExtreme (bundles/__internal/grids/data_grid/m_editing.js)
 * Version: 23.1.9
 * Build date: Mon Mar 11 2024
 *
 * Copyright (c) 2012 - 2024 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
require("./module_not_extended/editor_factory");
var _m_editing = require("../../grids/grid_core/editing/m_editing");
var _m_core = _interopRequireDefault(require("./m_core"));

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}

function _extends() {
    _extends = Object.assign ? Object.assign.bind() : function(target) {
        for (var i = 1; i < arguments.length; i++) {
            var source = arguments[i];
            for (var key in source) {
                if (Object.prototype.hasOwnProperty.call(source, key)) {
                    target[key] = source[key]
                }
            }
        }
        return target
    };
    return _extends.apply(this, arguments)
}

function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    _setPrototypeOf(subClass, superClass)
}

function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function(o, p) {
        o.__proto__ = p;
        return o
    };
    return _setPrototypeOf(o, p)
}
var data = function(Base) {
    return function(_dataControllerEditin) {
        _inheritsLoose(DataEditingDataGridExtender, _dataControllerEditin);

        function DataEditingDataGridExtender() {
            return _dataControllerEditin.apply(this, arguments) || this
        }
        var _proto = DataEditingDataGridExtender.prototype;
        _proto._changeRowExpandCore = function(key) {
            var editingController = this._editingController;
            if (Array.isArray(key)) {
                editingController && editingController.refresh()
            }
            return _dataControllerEditin.prototype._changeRowExpandCore.apply(this, arguments)
        };
        return DataEditingDataGridExtender
    }((0, _m_editing.dataControllerEditingExtenderMixin)(Base))
};
_m_core.default.registerModule("editing", _extends(_extends({}, _m_editing.editingModule), {
    extenders: _extends(_extends({}, _m_editing.editingModule.extenders), {
        controllers: _extends(_extends({}, _m_editing.editingModule.extenders.controllers), {
            data: data
        })
    })
}));

==> devextreme-23.2.5.tgz: package/bundles/__internal/grids/data_grid/m_editing.js <==
/**
 * DevExtreme (bundles/__internal/grids/data_grid/m_editing.js)
 * Version: 23.2.5
 * Build date: Mon Mar 11 2024
 *
 * Copyright (c) 2012 - 2024 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
require("./module_not_extended/editor_factory");
var _m_editing = require("../../grids/grid_core/editing/m_editing");
var _m_core = _interopRequireDefault(require("./m_core"));

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}

function _extends() {
    _extends = Object.assign ? Object.assign.bind() : function(target) {
        for (var i = 1; i < arguments.length; i++) {
            var source = arguments[i];
            for (var key in source) {
                if (Object.prototype.hasOwnProperty.call(source, key)) {
                    target[key] = source[key]
                }
            }
        }
        return target
    };
    return _extends.apply(this, arguments)
}

function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    _setPrototypeOf(subClass, superClass)
}

function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function(o, p) {
        o.__proto__ = p;
        return o
    };
    return _setPrototypeOf(o, p)
}
const data = Base => function(_dataControllerEditin) {
    _inheritsLoose(DataEditingDataGridExtender, _dataControllerEditin);

    function DataEditingDataGridExtender() {
        return _dataControllerEditin.apply(this, arguments) || this
    }
    var _proto = DataEditingDataGridExtender.prototype;
    _proto._changeRowExpandCore = function(key) {
        const editingController = this._editingController;
        if (Array.isArray(key)) {
            editingController && editingController.refresh()
        }
        return _dataControllerEditin.prototype._changeRowExpandCore.apply(this, arguments)
    };
    return DataEditingDataGridExtender
}((0, _m_editing.dataControllerEditingExtenderMixin)(Base));
_m_core.default.registerModule("editing", _extends(_extends({}, _m_editing.editingModule), {
    extenders: _extends(_extends({}, _m_editing.editingModule.extenders), {
        controllers: _extends(_extends({}, _m_editing.editingModule.extenders.controllers), {
            data: data
        })
    })
}));
